package shanghu

import (
	"duoduo/apis/shanghu/models"
	"duoduo/models/shanghu"
	"duoduo/tools/app"
	"github.com/gin-gonic/gin"
	"time"
)

func GetMerchantClientTicketAccountLog(c *gin.Context) {
	var inData models.GetMerchantRechargeClientAccountLogListRequest
	var sqlData shanghu.MerchantRechargeClientAccountLog
	var outDataList []models.GetMerchantRechargeClientAccountLogListReply

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	var pageSize = 10
	var pageIndex = 1

	if inData.PageSize != 0 {
		pageSize = inData.PageSize
	}
	if inData.PageIndex != 0 {
		pageIndex = inData.PageIndex
	}

	sqlData.MerchantOpenID = inData.MerchantOpenId
	cashOutList, count, err := sqlData.MerchantRechargeClientAccountLogList(pageSize, pageIndex)
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}

	for _, v := range cashOutList {
		var out models.GetMerchantRechargeClientAccountLogListReply
		var merchantClientUser shanghu.MerchantClientUser
		merchantClientUser.ClientOpenID = v.ClientOpenID

		userInfo, err := merchantClientUser.GetUserInfo()
		if err != nil {
			app.Error(c, 500, err, err.Error())
			return
		}

		var merchantRecharge shanghu.MerchantRecharge
		merchantRecharge.ID = v.PayTransID

		merchantRechargeInfo, err := merchantRecharge.GetMerchantRecharge()
		if err != nil {
			app.Error(c, 500, err, err.Error())
			return
		}

		out.Amount = v.Amount.String()
		out.ClientUserId = userInfo.Code
		out.RechargeName = merchantRechargeInfo.MerchantRechargeName
		out.RechargeTime = v.CreatedAt.Format(time.DateTime)
		outDataList = append(outDataList, out)

	}
	app.PageOK(c, outDataList, count, pageIndex, pageSize, app.Success)

}
