package shanghu

import (
	orm "duoduo/database"
	"time"
)

// 活动中奖配置，拼团配置，秒杀配置
type MerchantActiveConfig struct {
	ID                int64     `gorm:"column:id;type:bigint(20);primary_key;AUTO_INCREMENT" json:"id"`
	ConfigMode        int       `gorm:"column:config_mode;type:int(11)" json:"config_mode"`                    // 模式 1-默认模式
	MerchantOpenID    string    `gorm:"column:merchant_open_id;type:varchar(255)" json:"merchant_open_id"`     // openid
	DrawMode          int       `gorm:"column:draw_mode;type:int(11);default:0" json:"draw_mode"`              // 抽奖模式 0-不抽奖，1-盲盒
	DrawOneBiZhong    int64     `gorm:"column:draw_one_bi_zhong;type:bigint(20)" json:"draw_one_bi_zhong"`     // 首次必中抽奖商品ID
	DrawProduct       string    `gorm:"column:draw_product;type:json" json:"draw_product"`                     // 抽奖商品 商品ID 与中奖率
	CreateBy          int64     `gorm:"column:create_by;type:bigint(20)" json:"create_by"`                     // 创建者
	UpdateBy          int64     `gorm:"column:update_by;type:bigint(20)" json:"update_by"`                     // 更新者
	CreatedAt         time.Time `gorm:"column:created_at;type:datetime(3)" json:"created_at"`                  // 创建时间
	UpdatedAt         time.Time `gorm:"column:updated_at;type:datetime(3)" json:"updated_at"`                  // 最后更新时间
	DeletedAt         time.Time `gorm:"column:deleted_at;type:datetime(3);default:null" json:"deleted_at"`     // 删除时间
	GroupBuyMode      int       `gorm:"column:group_buy_mode;type:int(11)" json:"group_buy_mode"`              // 0-不开团 1-虚拟开团 2-真实开团
	GroupBuy          string    `gorm:"column:group_buy;type:json" json:"group_buy"`                           // 开团配置
	GroupBuyUrl       string    `gorm:"column:group_buy_url;type:varchar(255)" json:"group_buy_url"`           // 介绍图url
	ActivityEndTime   int64     `gorm:"column:activity_end_time;type:bigint(20)" json:"activity_end_time"`     // 活动结束时间
	ActivityStartTime int64     `gorm:"column:activity_start_time;type:bigint(20)" json:"activity_start_time"` // 活动开始时间
	ActiveName        string    `gorm:"column:active_name;type:varchar(255)" json:"active_name"`               // 活动名称
}

func (m *MerchantActiveConfig) TableName() string {
	return "merchant_active_config"
}

func (u *MerchantActiveConfig) Create() (MerchantActiveConfig, error) {
	var doc MerchantActiveConfig
	var err error

	doc = *u
	err = orm.ShMysql.Table(u.TableName()).Create(&doc).Error
	if err != nil {
		return doc, err
	}

	return doc, nil
}

func (m *MerchantActiveConfig) GetConfigInfoById() (MerchantActiveConfig, error) {
	var doc MerchantActiveConfig

	table := orm.ShMysql.Table(m.TableName())
	table = table.Where("id = ?  ", m.ID)

	if err := table.Select("*").First(&doc).Error; err != nil {
		return doc, err
	}

	return doc, nil
}

func (m *MerchantActiveConfig) GetActiveConfigList(pageSize int, pageIndex int) ([]MerchantActiveConfig, int, error) {
	var doc []MerchantActiveConfig

	table := orm.ShMysql.Table(m.TableName())

	table = table.Where("merchant_open_id = ?  ", m.MerchantOpenID)
	var count int
	if err := table.Select("*").Order("id desc").Offset((pageIndex - 1) * pageSize).Limit(pageSize).Find(&doc).Error; err != nil {
		return nil, 0, err
	}
	table.Count(&count)
	return doc, count, nil
}
